@@ -7,7 +7,7 @@ use base 'DBIx::dbMan::Interface';
 
 require Tk::ROText;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 
@@ -125,6 +125,10 @@ sub can_pager {
 	return 0;
 }
 
+sub is_utf8 {
+    return 1;
+}
+
 # what is needed in this tkgui ?
 # ... registering/unregistering menu items
 # ... starting handle event from menu items and other actions (bind etc.)
